@@ -108,25 +108,14 @@ class QolsysTable:
             if self._abort_on_error:
                 raise error from err
 
-    def update(self, selection: str, selection_argument: str, content_value: str) -> None:
+    def update(self, selection: str | None, selection_argument: list | str | None, content_value: str | None) -> None:
         # selection: 'zone_id=?, parition_id=?'
-
-        # selection_argument:
         # Firmware 4.4.1: selection_argument: '[3,1]'
         # Firmware 4.6.1: selection_argument: ['3','1']
         # contentValues:{"partition_id":"0","sensorgroup":"safetymotion","sensorstatus":"Idle"}"
 
-        if selection_argument == "":
-            LOGGER.debug("Update called with empty selection_argument")
-            LOGGER.debug("Table: %s", self.table)
-            LOGGER.debug("Selection: %s", selection)
-            LOGGER.debug("selection_argument: %s", selection_argument)
-            return
-
-        # Selection Argument
-        # Panel send selection_argument as list in Firmware 4.6.1
-        if(type(selection_argument) is not list):
-            #Firmware 4.4.1, seletion_argument is sent as a string
+        # Firmware 4.4.1: seletion_argument is sent as a string and needs to be converted to an array
+        if(type(selection_argument) is str):
             selection_argument = selection_argument.strip("[]")
             selection_argument = [item.strip() for item in selection_argument.split(",")]
 
@@ -149,8 +138,13 @@ class QolsysTable:
                 LOGGER.warning("New Columns: %s", new_columns)
                 LOGGER.warning("Please Report")
 
-            query = f"UPDATE {self.table} SET {db_value} WHERE {selection}"
-            self._cursor.execute(query, selection_argument)
+            if selection:
+                query = f"UPDATE {self.table} SET {db_value} WHERE {selection}"
+                self._cursor.execute(query, selection_argument)
+            else:
+                query = f"UPDATE {self.table} SET {db_value}"
+                self._cursor.execute(query)
+
             self._db.commit()
 
         except sqlite3.Error as err:
@@ -166,28 +160,23 @@ class QolsysTable:
             if self._abort_on_error:
                 raise error from err
 
-    def delete(self, selection: str, selection_argument: str) -> None:
+    def delete(self, selection: str | None, selection_argument: list | str | None) -> None:
         # selection: 'zone_id=?, parition_id=?'
         # Firmware 4.4.1: selection_argument: '[3,1]'
         # Firmware 4.6.1: selection_argument: ['3','1']
 
-
-        if selection_argument == "":
-            LOGGER.debug("Delete called with empty selection_argument")
-            LOGGER.debug("Table: %s", self.table)
-            LOGGER.debug("Selection: %s", selection)
-            LOGGER.debug("selection_argument: %s", selection_argument)
-            return
-
-        # Selection Argument
-        if(type(selection_argument) is not list):
-            #Firmware 4.4.1, seletion_argument is sent as a string
+        # Firmware 4.4.1: seletion_argument is sent as a string and needs to be converted to an array
+        if(type(selection_argument) is str):
             selection_argument = selection_argument.strip("[]")
             selection_argument = [item.strip() for item in selection_argument.split(",")]
 
         try:
-            query = f"DELETE FROM {self.table} WHERE {selection}"
-            self._cursor.execute(query, selection_argument)
+            if selection:
+                query = f"DELETE FROM {self.table} WHERE {selection}"
+                self._cursor.execute(query, selection_argument)
+            else:
+                self.clear()
+
             self._db.commit()
 
         except sqlite3.Error as err:
