@@ -354,7 +354,6 @@ class QolsysPanel(QolsysObservable):
         self._controller.state.sync_scenes_data(self.get_scenes_from_db())
         self._controller.state.sync_weather_data(self.get_weather_from_db())
 
-
     # Parse panel update to database
     def parse_iq2meid_message(self, data: dict) -> bool:  # noqa: C901, PLR0912, PLR0915
 
@@ -376,12 +375,8 @@ class QolsysPanel(QolsysObservable):
 
                     case "update":
                         content_values = data.get("contentValues","")
-                        selection = data.get("selection","")
-                        selection_argument = data.get("selectionArgs","")
-
-                        if selection_argument == "" or selection == "":
-                            LOGGER.debug("iq2meid invalid update selection or selectionArgs")
-                            LOGGER.debug("data:%s", data)
+                        selection = data.get("selection")
+                        selection_argument = data.get("selectionArgs")
 
                         match uri:
 
@@ -437,17 +432,14 @@ class QolsysPanel(QolsysObservable):
                             # Update heat_map
                             case self.db.table_heat_map.uri:
                                 self.db.table_heat_map.update(selection, selection_argument, content_values)
-                                # No action needed
 
                             # Update master_slave
                             case self.db.table_master_slave.uri:
                                 self.db.table_master_slave.update(selection, selection_argument, content_values)
-                                # No action needed
 
                             # Update dashboard_msgs
                             case self.db.table_dashboard_msgs.uri:
                                 self.db.table_dashboard_msgs.update(selection, selection_argument, content_values)
-                                # No action needed
 
                             # Update PartitionContentProvider
                             case self.db.table_partition.uri:
@@ -460,7 +452,6 @@ class QolsysPanel(QolsysObservable):
                             # Update History Content Provider
                             case self.db.table_history.uri:
                                 self.db.table_history.update(selection, selection_argument, content_values)
-                                # No action needed
 
                             # Update DimmerLightsContentProvider
                             case self.db.table_dimmer.uri:
@@ -497,12 +488,10 @@ class QolsysPanel(QolsysObservable):
                             # Update Z-Wave History Content Provier
                             case self.db.table_zwave_history.uri:
                                 self.db.table_zwave_history.update(selection, selection_argument, content_values)
-                                # No action needed
 
                             # Update AutomationDeviceContentProvider
                             case self.db.table_automation.uri:
                                 self.db.table_automation.update(selection, selection_argument, content_values)
-                                # No action needed
 
                             # Update Alarmed Sensor Content Provider
                             case self.db.table_alarmedsensor.uri:
@@ -511,7 +500,6 @@ class QolsysPanel(QolsysObservable):
                             # Update IQ Remote Settings Content Provider
                             case self.db.table_iqremotesettings.uri:
                                 self.db.table_iqremotesettings.update(selection, selection_argument, content_values)
-                                # No action needed
 
                             # Update Scene Content Provider
                             case self.db.table_scene.uri:
@@ -524,12 +512,10 @@ class QolsysPanel(QolsysObservable):
                             # Update Trouble Conditions
                             case self.db.table_trouble_conditions.uri:
                                 self.db.table_trouble_conditions.update(selection,selection_argument,content_values)
-                                # No action needed
 
                             # Update EU_EVENT:
                             case self.db.table_eu_event.uri:
                                 self.db.table_eu_event.update(selection,selection_argument,content_values)
-                                # No action needed
 
                             # Update PowerG Device
                             case self.db.table_powerg_device.uri:
@@ -537,48 +523,38 @@ class QolsysPanel(QolsysObservable):
                                 short_id = content_values.get("shortID", "")
                                 zone = self._controller.state.zone_from_short_id(short_id)
                                 if zone is not None:
-                                    LOGGER.debug("iq2meid updating powerg device for zoneid(%s):%s", zone.zone_id,content_values)
                                     zone.update_powerg(content_values)
 
                             # Update Weather
                             case self.db.table_weather.uri:
                                 self.db.table_weather.update(selection,selection_argument,content_values)
-                                self._controller.sync_weather_data(self.get_weather_from_db())
+                                self._controller.state.sync_weather_data(self.get_weather_from_db())
 
                             case _:
                                 LOGGER.debug("iq2meid updating unknow uri:%s", uri)
                                 LOGGER.debug(data)
 
                     case "delete":
-                        selection = data.get("selection","")
-                        selection_argument = data.get("selectionArgs","")
-
-                        if selection_argument == "" or selection == "":
-                            LOGGER.debug("iq2meid invalid delete selection or selectionArgs")
-                            LOGGER.debug("data:%s", data)
+                        selection = data.get("selection")
+                        selection_argument = data.get("selectionArgs")
 
                         match uri:
 
                             case self.db.table_sensor.uri:
                                 self.db.table_sensor.delete(selection, selection_argument)
                                 self._controller.state.sync_zones_data(self.get_zones_from_db())
-                                # Notify delete zone
 
                             case self.db.table_iqremotesettings.uri:
                                 self.db.table_iqremotesettings.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_state.uri:
                                 self.db.table_state.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_master_slave.uri:
                                 self.db.table_master_slave.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_qolsyssettings.uri:
                                 self.db.table_qolsyssettings.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_alarmedsensor.uri:
                                 self.db.table_alarmedsensor.delete(selection, selection_argument)
@@ -586,11 +562,9 @@ class QolsysPanel(QolsysObservable):
 
                             case self.db.table_history.uri:
                                 self.db.table_history.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_zwave_history.uri:
                                 self.db.table_zwave_history.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_doorlock.uri:
                                 self.db.table_doorlock.delete(selection, selection_argument)
@@ -610,7 +584,6 @@ class QolsysPanel(QolsysObservable):
 
                             case self.db.table_automation.uri:
                                 self.db.table_automation.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_partition.uri:
                                 self.db.table_partition.delete(selection, selection_argument)
@@ -618,11 +591,9 @@ class QolsysPanel(QolsysObservable):
 
                             case self.db.table_user.uri:
                                 self.db.table_user.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_dashboard_msgs.uri:
                                 self.db.table_dashboard_msgs.delete(selection, selection_argument)
-                                # No action needed
 
                             case self.db.table_eu_event.uri:
                                 self.db.table_eu_event.delete(selection,selection_argument)
@@ -632,7 +603,7 @@ class QolsysPanel(QolsysObservable):
 
                             case self.db.table_weather.uri:
                                 self.db.table_weather.delete(selection,selection_argument)
-                                self._controller.sync_weather_data(self.get_weather_from_db())
+                                self._controller.state.sync_weather_data(self.get_weather_from_db())
 
                             case _:
                                 LOGGER.debug("iq2meid deleting unknown uri:%s", uri)
@@ -726,7 +697,6 @@ class QolsysPanel(QolsysObservable):
                             # HistoryContentProvider
                             case self.db.table_history.uri:
                                 self.db.table_history.insert(data=content_values)
-                                # No action needed
 
                             # AlarmedSensorProvider
                             case self.db.table_alarmedsensor.uri:
@@ -741,22 +711,18 @@ class QolsysPanel(QolsysObservable):
                             # IQRemoteSettingsProvider
                             case self.db.table_iqremotesettings.uri:
                                 self.db.table_iqremotesettings.insert(data=content_values)
-                                # No action needed
 
                             # HeatMapContentProvider
                             case self.db.table_heat_map.uri:
                                 self.db.table_heat_map.insert(data=content_values)
-                                # No action needed
 
                             # ZDeviceHistoryContentProvider
                             case self.db.table_zwave_history.uri:
                                 self.db.table_zwave_history.insert(data=content_values)
-                                # No action needed
 
                             # Dashboard Message Content Provider
                             case self.db.table_dashboard_msgs.uri:
                                 self.db.table_dashboard_msgs.insert(data=content_values)
-                                # No action needed
 
                             # EU_EVENT
                             case self.db.table_eu_event.uri:
@@ -769,7 +735,7 @@ class QolsysPanel(QolsysObservable):
                             # Weather
                             case self.db.table_weather.uri:
                                 self.db.table_weather.insert(data=content_values)
-                                self._controller.sync_weather_data(self.get_weather_from_db())
+                                self._controller.state.sync_weather_data(self.get_weather_from_db())
 
                             case _:
                                 LOGGER.debug("iq2meid inserting unknow uri:%s", uri)
