@@ -3,8 +3,6 @@ from __future__ import annotations
 import logging
 from typing import TYPE_CHECKING
 
-from qolsys_controller.database import db
-
 from .observable import QolsysObservable
 from .weather import QolsysWeather
 from .zwave_device import QolsysZWaveDevice
@@ -261,10 +259,6 @@ class QolsysState(QolsysObservable):
                             state_zwave.update_base(db_zwave.to_dict_base())
                             break
 
-                        # zwave node_id has changed of node_type, delete and add again
-                        # self.zwave_delete(int(state_zwave.node_id))
-                        # self.zwave_add(db_zwave)
-
         # Add new zwave device
         for db_zwave in db_zwaves:
             if db_zwave.node_id not in state_zwave_list:
@@ -433,7 +427,7 @@ class QolsysState(QolsysObservable):
             if isinstance(zwave, QolsysLock):
                 zid = zwave.lock_node_id
                 name = zwave.lock_name
-                LOGGER.debug("Lock%s (%s) - current_temp: %s", zid, name, zwave.lock_status)
+                LOGGER.debug("Lock%s (%s) - lock_status: %s", zid, name, zwave.lock_status)
                 continue
 
             if isinstance(zwave, QolsysGeneric):
@@ -451,4 +445,4 @@ class QolsysState(QolsysObservable):
             LOGGER.debug("Scene%s (%s)",sid, name)
 
         for forecast in self.weather.forecasts:
-            LOGGER.debug("Weather - %s - High: %s, Low:%s, Condition:%s", forecast.day_of_week[0:3],forecast.high_temp,forecast.low_temp,forecast.condition)
\ No newline at end of file
+            LOGGER.debug("Weather - %s - High: %s, Low:%s, Condition: %s", forecast.day_of_week[0:3],forecast.high_temp,forecast.low_temp,forecast.condition)
